@@ -36,11 +36,11 @@ TAP::Formatter::Console::Session - Harness output delegate for default console o
 
 =head1 VERSION
 
-Version 2.99_05
+Version 2.99_06
 
 =cut
 
-$VERSION = '2.99_05';
+$VERSION = '2.99_06';
 
 =head1 DESCRIPTION
 
@@ -231,7 +231,13 @@ sub _closures {
                 $formatter->$output("\r$spaces\r$pretty");
             }
 
-            unless ( $parser->has_problems ) {
+            if ( my $skip_all = $parser->skip_all ) {
+                $formatter->_output("skipped: $skip_all\n");
+            }
+            elsif ( $parser->has_problems ) {
+                $self->_output_test_failure($parser);
+            }
+            else {
                 unless ($really_quiet) {
                     my $time_report = '';
                     if ( $formatter->timer ) {
@@ -249,9 +255,6 @@ sub _closures {
                     $formatter->_output("ok$time_report\n");
                 }
             }
-            else {
-                $self->_output_test_failure($parser);
-            }
         },
     };
 }
